import React, { Component, Fragment } from 'react';
import { isPinValid, ERROR_CODES, isPinSymbolsValid } from '../../../helpers/pin-code';
import { PincodeGroup } from '../pincode-group/pincode-group';


const PIN_CODE_INPUT_ID = 'wallet-pin-code-input';
const PIN_CODE_CONFIRM_INPUT_ID = 'wallet-pin-code-confirm-input';

export class PinCodes extends Component {
  state = {
    pinCode: '',
    pinCodeError: null,
    pinCodeConfirm: '',
    pinCodeConfirmError: null,
  };

  submit = () => {
    const { pinCode, pinCodeConfirm } = this.state;
    const isPinCodeValid = isPinValid(pinCode);
    const isPinCodeConfirmValid = isPinValid(pinCodeConfirm);
    if (!isPinCodeValid || !isPinCodeConfirmValid) {
      let pinCodeErrorMessage = null;
      let pinCodeConfirmErrorMessage = null;
      if (!isPinCodeValid) {
        pinCodeErrorMessage = ERROR_CODES.INCORRECT_LENGTH;
      }
      if (!isPinCodeConfirmValid) {
        pinCodeConfirmErrorMessage = ERROR_CODES.INCORRECT_LENGTH;
      }

      this.setState({
        pinCodeError: pinCodeErrorMessage,
        pinCodeConfirmError: pinCodeConfirmErrorMessage,
      });
    } else if (pinCode !== pinCodeConfirm) {
      this.setState({
        pinCodeError: null,
        pinCodeConfirmError: ERROR_CODES.PINS_DONT_MATCH,
      });
    } else {
      return pinCode;
    }
    return null;
  };

  setPinCode = (pinCode) => {
    if (isPinSymbolsValid(pinCode)) {
      this.setState({ pinCode, pinCodeError: null });
    }
  };

  setPinCodeConfirm = (pinCodeConfirm) => {
    if (isPinSymbolsValid(pinCodeConfirm)) {
      this.setState({ pinCodeConfirm, pinCodeConfirmError: null });
    }
  };

  render() {
    const {
      pinCode, pinCodeError, pinCodeConfirm, pinCodeConfirmError,
    } = this.state;

    return (
      <Fragment>
        <PincodeGroup
          id={PIN_CODE_INPUT_ID}
          value={pinCode}
          label="wallet.sign-in.create-pin.pin-first.input-text"
          name="pin-code"
          bsSize="lg"
          className="w-100"
          inputError={pinCodeError}
          setPinCode={this.setPinCode}
        />
        <PincodeGroup
          id={PIN_CODE_CONFIRM_INPUT_ID}
          value={pinCodeConfirm}
          label="wallet.sign-in.create-pin.pin-confirm.input-text"
          name="pin-code-confirm"
          bsSize="lg"
          className="w-100"
          inputError={pinCodeConfirmError}
          setPinCode={this.setPinCodeConfirm}
        />
      </Fragment>
    );
  }
}
